@@ -10,7 +10,7 @@ from elasticsearch.exceptions import ElasticsearchWarning
 
 from .defines import BVX_PYTEST_DOCKER_ES_IMAGE_NAME, \
     BVX_PYTEST_DOCKER_ES_CONTAINER_NAME, \
-    BVX_PYTEST_DOCKER_ES_PORT_ENV_KEY
+    BVX_PYTEST_DOCKER_ES_PORT_ENV_KEY, BVX_PYTEST_DOCKER_ES_HOST_ENV_KEY
 from ..defines import BVX_PYTEST_DOCKER_NETWORK_NAME
 
 
@@ -18,6 +18,9 @@ def setup_function():
     warnings.resetwarnings()
     warnings.simplefilter('ignore', ElasticsearchWarning)
 
+    # set host
+    _es_host = '127.0.0.1'
+
     # find free port for elasticsearch
     _es_port = unused_port_number()
 
@@ -65,13 +68,16 @@ def setup_function():
         ports={f'9200/tcp': _es_port}
     )
 
+    # set elasticsearch port to environment.
+    os.environ[BVX_PYTEST_DOCKER_ES_HOST_ENV_KEY] = str(_es_host)
+
     # set elasticsearch port to environment.
     os.environ[BVX_PYTEST_DOCKER_ES_PORT_ENV_KEY] = str(_es_port)
 
     # wait for launch.
     while True:
         try:
-            requests.get(f'http://127.0.0.1:{_es_port}', timeout=(1.0, 1.0))
+            requests.get(f'http://{_es_host}:{_es_port}', timeout=(1.0, 1.0))
             break
         except requests.exceptions.ConnectionError:
             time.sleep(1)
