@@ -1,10 +1,16 @@
+import warnings
+
 import docker
 from bvx_docker import container_exists
+from elasticsearch.exceptions import ElasticsearchWarning
 
 from .defines import BVX_PYTEST_DOCKER_ES_CONTAINER_NAME
 
 
 def teardown_function():
+    warnings.resetwarnings()
+    warnings.simplefilter('ignore', ElasticsearchWarning)
+
     # create docker client
     _client = docker.from_env()
 
